@@ -1,9 +1,10 @@
 package Twitter::API::Trait::AppAuth;
 # ABSTRACT: App-only (OAuth2) Authentication
-$Twitter::API::Trait::AppAuth::VERSION = '0.0101'; # TRIAL
+$Twitter::API::Trait::AppAuth::VERSION = '0.0102'; # TRIAL
 use Moo::Role;
 use Carp;
 use HTTP::Request::Common qw/POST/;
+use URL::Encode qw/url_encode url_decode/;
 use namespace::clean;
 
 # private methods
@@ -23,15 +24,38 @@ my $add_consumer_auth_header = sub {
 
 # public methods
 
+#pod =method get_bearer_token
+#pod
+#pod Call the C<oauth2/token> endpoint to get a bearer token. The token is not
+#pod stored in Twitter::API's state. If you want that, set the C<access_token>
+#pod attribute with the returned token.
+#pod
+#pod See L<https://dev.twitter.com/oauth/reference/post/oauth2/token> for details.
+#pod
+#pod =cut
+
 sub get_bearer_token {
     my $self = shift;
 
-    $self->request(post => $self->oauth2_url_for('token'), {
+    my $r = $self->request(post => $self->oauth2_url_for('token'), {
         -add_consumer_auth_header => 1,
         grant_type => 'client_credentials',
     });
+
+    # In their wisdom, Twitter sends us a URL encoded token. We need to decode
+    # it, so if/when we call invalidate_token, and properly URL encode our
+    # parameters, we don't end up with a double-encoded token.
+    return url_decode($$r{access_token});
 }
 
+#pod =method invalidate_token($token)
+#pod
+#pod Calls the C<oauth2/invalidate_token> endpoint to revoke a token. See
+#pod L<https://dev.twitter.com/oauth/reference/post/oauth2/invalidate/token> for
+#pod details.
+#pod
+#pod =cut
+
 sub invalidate_token {
     my ( $self, $token ) = @_;
 
@@ -52,7 +76,7 @@ around add_authorization => sub {
 
     my $token = $c->get_option('token') // $self->access_token // return;
 
-    $c->set_header(authorization => join ' ', Bearer => $token);
+    $c->set_header(authorization => join ' ', Bearer => url_encode($token));
 };
 
 around finalize_request => sub {
@@ -78,7 +102,7 @@ Twitter::API::Trait::AppAuth - App-only (OAuth2) Authentication
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
@@ -104,6 +128,22 @@ version 0.0101
     # if you revoke the token stored in the access_token attribute, clear it:
     $client->clear_access_token;
 
+=head1 METHODS
+
+=head2 get_bearer_token
+
+Call the C<oauth2/token> endpoint to get a bearer token. The token is not
+stored in Twitter::API's state. If you want that, set the C<access_token>
+attribute with the returned token.
+
+See L<https://dev.twitter.com/oauth/reference/post/oauth2/token> for details.
+
+=head2 invalidate_token($token)
+
+Calls the C<oauth2/invalidate_token> endpoint to revoke a token. See
+L<https://dev.twitter.com/oauth/reference/post/oauth2/invalidate/token> for
+details.
+
 =head1 AUTHOR
 
 Marc Mims <marc@questright.com>
