@@ -1,6 +1,6 @@
 package Twitter::API::Trait::Enchilada;
-# ABSTRACT: Sometimes you wan the whole enchilada
-$Twitter::API::Trait::Enchilada::VERSION = '0.0101'; # TRIAL
+# ABSTRACT: Sometimes you want the whole enchilada
+$Twitter::API::Trait::Enchilada::VERSION = '0.0102'; # TRIAL
 use Moo::Role;
 use namespace::clean;
 
@@ -24,11 +24,11 @@ __END__
 
 =head1 NAME
 
-Twitter::API::Trait::Enchilada - Sometimes you wan the whole enchilada
+Twitter::API::Trait::Enchilada - Sometimes you want the whole enchilada
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
@@ -39,22 +39,31 @@ version 0.0101
         %other_new_options
     );
 
-    # which is just shorthand for:
-    my $client = Twitter::API->new_with_traits(
-        traits => [ qw/
-            ApiMethods
-            NormalizeBooleans
-            RetryOnError
-            DecodeHtmlEntities
-        /],
-        %other_new_options
-    );
-
 =head1 DESCRIPTION
 
-This is just a shortcut for applying traits ApiMethods, NormalizeBooleans,
-RetryOnError, and DecodeHtmlEntities. Because sometimes you just want the whole
-enchilada.
+This is just a shortcut for applying commonly used traits. Because, sometimes, you just want the whole enchilada.
+
+This role simply bundles the following traits. See those modules for details.
+
+=over 4
+
+=item *
+
+L<ApiMethods|Twitter::API::Trait::ApiMethods>
+
+=item *
+
+L<NormalizeBooleans|Twitter::API::Trait::NormalizeBooleans>
+
+=item *
+
+L<RetryOnError|Twitter::API::Trait::RetryOnError>
+
+=item *
+
+L<DecodeHtmlEntites|Twitter::API::Trait::DecodeHtmlEntities>
+
+=back
 
 =head1 AUTHOR
 
